pub struct Progress {
pub tag: String,
pub title: String,
pub status: String,
pub value: f32,
pub value_string: String,
}Fields
tag: StringDefine a tag to uniquely identify the notification, in order update the notification data later.
title: StringGets or sets an optional title string. Supports data binding.
status: StringGets or sets a status string (required), which is displayed underneath the progress bar on the left. This string should reflect the status of the operation, like “Downloading…” or “Installing…”
value: f32Gets or sets the value of the progress bar. Supports data binding. Defaults to 0. Can either be a double between 0.0 and 1.0,
value_string: StringGets or sets an optional string to be displayed instead of the default percentage string.